@@ -77,9 +77,11 @@ def load(mesh_path, triangulate=False):
                 "OBJ Loader does not support arities greater than 4 or less than 3"
             )
         is_mixed_arity = np.any(all_vertices_per_face != first_arity)
-        all_faces = np.zeros((0, 3 if triangulate else first_arity), dtype=np.uint64)
+        index_dtype = all_vertices_per_face.dtype
+        all_faces = np.zeros((0, 3 if triangulate else first_arity), dtype=index_dtype)
     else:
-        all_faces = np.zeros((0, 3), dtype=np.uint64)
+        index_dtype = np.int32
+        all_faces = np.zeros((0, 3), dtype=index_dtype)
 
     segm = OrderedDict()
 
@@ -91,7 +93,7 @@ def load(mesh_path, triangulate=False):
             )
         elif is_mixed_arity:
             these_vertices_per_face = shape.mesh.numpy_num_face_vertices()
-            these_faces = np.zeros((0, 3), dtype=np.uint64)
+            these_faces = np.zeros((0, 3), dtype=index_dtype)
             for this_face in unstack(tinyobj_all_indices, these_vertices_per_face):
                 if len(this_face) == 3:
                     these_faces = np.concatenate([these_faces, this_face.reshape(1, 3)])
